@@ -10,7 +10,7 @@
 from torch.utils.data import Dataset
 import torchvision.datasets as datasets
 
-from .evaluator.imagenet import ImageNetEvaluator
+from .evaluator.general_evaluator import GeneralEvaluator
 
 
 class ImageNet(Dataset):
@@ -24,7 +24,9 @@ class ImageNet(Dataset):
         split = 'train' if train else 'val'
 
         self.data_set = datasets.ImageNet(root, split=split, transform=transform, target_transform=target_transform)
-        self.classes = self.data_set.classes
+        self.classes = list()
+        for class_tuple in self.data_set.classes:
+            self.classes.append(','.join(class_tuple))
         self._update_evaluator()
 
     def __getitem__(self, index: int):
@@ -34,4 +36,4 @@ class ImageNet(Dataset):
         return self.data_set.__len__()
 
     def _update_evaluator(self):
-        self.evaluator = ImageNetEvaluator(self.classes, topk=(1, 5))
+        self.evaluator = GeneralEvaluator(self.classes, topk=(1, 5))
