@@ -21,6 +21,7 @@ from zcls.util.metric_logger import MetricLogger, update_stats, log_iter_stats,
 from zcls.util.precise_bn import calculate_and_update_precise_bn
 from zcls.util.distributed import is_master_proc, synchronize
 from zcls.util import logging
+from zcls.util.prefetcher import Prefetcher
 from zcls.engine.inference import do_evaluation
 from zcls.data.build import shuffle_dataset
 
@@ -50,8 +51,11 @@ def do_train(cfg, arguments,
     max_iter = (max_epoch - start_epoch) * epoch_iters
     current_iterations = 0
 
-    # Creates a GradScaler once at the beginning of training.
-    scaler = GradScaler()
+    data_loader = Prefetcher(train_data_loader) if cfg.DATALOADER.PREFETCHER else train_data_loader
+
+    if cfg.TRAIN.HYBRID_PRECISION:
+        # Creates a GradScaler once at the beginning of training.
+        scaler = GradScaler()
 
     synchronize()
     model.train()
@@ -62,30 +66,50 @@ def do_train(cfg, arguments,
     end = time.time()
     for cur_epoch in range(start_epoch, max_epoch + 1):
         shuffle_dataset(train_data_loader, cur_epoch)
-        for iteration, (images, targets) in enumerate(train_data_loader):
-            images = images.to(device=device, non_blocking=True)
-            targets = targets.to(device=device, non_blocking=True)
+        for iteration, (images, targets) in enumerate(data_loader):
+            if not cfg.DATALOADER.PREFETCHER:
+                images = images.to(device=device, non_blocking=True)
+                targets = targets.to(device=device, non_blocking=True)
 
-            # Runs the forward pass with autocasting.
-            with autocast():
+            if cfg.TRAIN.HYBRID_PRECISION:
+                # Runs the forward pass with autocasting.
+                with autocast():
+                    output_dict = model(images)
+                    loss_dict = criterion(output_dict, targets)
+                    loss = loss_dict[KEY_LOSS] / gradient_accumulate_step
+
+                current_iterations += 1
+                if current_iterations % gradient_accumulate_step != 0:
+                    if isinstance(model, DistributedDataParallel):
+                        # multi-gpu distributed training
+                        with model.no_sync():
+                            scaler.scale(loss).backward()
+                    else:
+                        scaler.scale(loss).backward()
+                else:
+                    scaler.scale(loss).backward()
+                    scaler.step(optimizer)
+                    scaler.update()
+                    current_iterations = 0
+                    optimizer.zero_grad()
+            else:
                 output_dict = model(images)
                 loss_dict = criterion(output_dict, targets)
                 loss = loss_dict[KEY_LOSS] / gradient_accumulate_step
 
-            current_iterations += 1
-            if current_iterations % gradient_accumulate_step != 0:
-                if isinstance(model, DistributedDataParallel):
-                    # multi-gpu distributed training
-                    with model.no_sync():
-                        scaler.scale(loss).backward()
+                current_iterations += 1
+                if current_iterations % gradient_accumulate_step != 0:
+                    if isinstance(model, DistributedDataParallel):
+                        # multi-gpu distributed training
+                        with model.no_sync():
+                            loss.backward()
+                    else:
+                        loss.backward()
                 else:
-                    scaler.scale(loss).backward()
-            else:
-                scaler.scale(loss).backward()
-                scaler.step(optimizer)
-                scaler.update()
-                current_iterations = 0
-                optimizer.zero_grad()
+                    loss.backward()
+                    optimizer.step()
+                    current_iterations = 0
+                    optimizer.zero_grad()
 
             acc_list = evaluator.evaluate_train(output_dict, targets)
             update_stats(cfg.NUM_GPUS, meters, loss_dict, acc_list)
